@@ -36,9 +36,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
     message_listeners: List[
         Union[
             AsyncWebSocketMessageListener,
-            Callable[
-                ["AsyncBaseSocketModeClient", dict, Optional[str]], Awaitable[None]
-            ],
+            Callable[["AsyncBaseSocketModeClient", dict, Optional[str]], Awaitable[None]],
         ]
     ]
     socket_mode_request_listeners: List[
@@ -78,9 +76,9 @@ class SocketModeClient(AsyncBaseSocketModeClient):
         auto_reconnect_enabled: bool = True,
         ping_interval: float = 5,
         trace_enabled: bool = False,
-        on_message_listeners: Optional[List[Callable[[WSMessage], None]]] = None,
-        on_error_listeners: Optional[List[Callable[[WSMessage], None]]] = None,
-        on_close_listeners: Optional[List[Callable[[WSMessage], None]]] = None,
+        on_message_listeners: Optional[List[Callable[[WSMessage], Awaitable[None]]]] = None,
+        on_error_listeners: Optional[List[Callable[[WSMessage], Awaitable[None]]]] = None,
+        on_close_listeners: Optional[List[Callable[[WSMessage], Awaitable[None]]]] = None,
     ):
         """Socket Mode client
 
@@ -143,9 +141,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
         session_id: str = self.build_session_id(session)
 
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"A new monitor_current_session() execution loop for {session_id} started"
-            )
+            self.logger.debug(f"A new monitor_current_session() execution loop for {session_id} started")
         try:
             logging_interval = 100
             counter_for_logging = 0
@@ -153,21 +149,21 @@ class SocketModeClient(AsyncBaseSocketModeClient):
             while not self.closed:
                 if session != self.current_session:
                     if self.logger.level <= logging.DEBUG:
-                        self.logger.debug(
-                            f"The monitor_current_session task for {session_id} is now cancelled"
-                        )
+                        self.logger.debug(f"The monitor_current_session task for {session_id} is now cancelled")
                     break
                 try:
-                    # The logging here is for detailed trouble shooting of potential issues in this client.
-                    # If you don't see this log for a while, it means that
-                    # this receive_messages execution is no longer working for some reason.
-                    counter_for_logging = (counter_for_logging + 1) % logging_interval
-                    if counter_for_logging == 0:
-                        log_message = (
-                            f"{logging_interval} session verification executed after the previous same log"
-                            f" ({session_id})"
-                        )
-                        self.logger.debug(log_message)
+                    if self.trace_enabled and self.logger.level <= logging.DEBUG:
+                        # The logging here is for detailed investigation on potential issues in this client.
+                        # If you don't see this log for a while, it means that
+                        # this receive_messages execution is no longer working for some reason.
+                        counter_for_logging += 1
+                        if counter_for_logging >= logging_interval:
+                            counter_for_logging = 0
+                            log_message = (
+                                "#monitor_current_session method has been verifying if this session is active "
+                                f"(session: {session_id}, logging interval: {logging_interval})"
+                            )
+                            self.logger.debug(log_message)
 
                     await asyncio.sleep(self.ping_interval)
 
@@ -181,22 +177,16 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                             # The ping() method can fail for some reason.
                             # To establish a new connection even in this scenario,
                             # we ignore the exception here.
-                            self.logger.warning(
-                                f"Failed to send a ping message ({session_id}): {e}"
-                            )
+                            self.logger.warning(f"Failed to send a ping message ({session_id}): {e}")
 
                     if self.auto_reconnect_enabled:
                         should_reconnect = False
                         if session is None or session.closed:
-                            self.logger.info(
-                                f"The session ({session_id}) seems to be already closed. Reconnecting..."
-                            )
+                            self.logger.info(f"The session ({session_id}) seems to be already closed. Reconnecting...")
                             should_reconnect = True
 
                         if await self.is_ping_pong_failing():
-                            disconnected_seconds = int(
-                                time.time() - self.last_ping_pong_time
-                            )
+                            disconnected_seconds = int(time.time() - self.last_ping_pong_time)
                             self.logger.info(
                                 f"The session ({session_id}) seems to be stale. Reconnecting..."
                                 f" reason: disconnected for {disconnected_seconds}+ seconds)"
@@ -215,9 +205,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                     )
         except asyncio.CancelledError:
             if self.logger.level <= logging.DEBUG:
-                self.logger.debug(
-                    f"The monitor_current_session task for {session_id} is now cancelled"
-                )
+                self.logger.debug(f"The monitor_current_session task for {session_id} is now cancelled")
             raise
 
     async def receive_messages(self) -> None:
@@ -227,9 +215,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
         session = self.current_session
         session_id = self.build_session_id(session)
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"A new receive_messages() execution loop with {session_id} started"
-            )
+            self.logger.debug(f"A new receive_messages() execution loop with {session_id} started")
         try:
             consecutive_error_count = 0
             logging_interval = 100
@@ -238,44 +224,43 @@ class SocketModeClient(AsyncBaseSocketModeClient):
             while not self.closed:
                 if session != self.current_session:
                     if self.logger.level <= logging.DEBUG:
-                        self.logger.debug(
-                            f"The running receive_messages task for {session_id} is now cancelled"
-                        )
+                        self.logger.debug(f"The running receive_messages task for {session_id} is now cancelled")
                     break
                 try:
                     message: WSMessage = await session.receive()
-                    if self.trace_enabled and self.logger.level <= logging.DEBUG:
-                        # The following logging prints every single received message except empty message data ones.
-                        type = WSMsgType(message.type)
-                        message_type = type.name if type is not None else message.type
-                        message_data = message.data
-                        if isinstance(message_data, bytes):
-                            message_data = message_data.decode("utf-8")
-                        if len(message_data) > 0:
-                            # To skip the empty message that Slack server-side often sends
-                            self.logger.debug(
-                                f"Received message "
-                                f"(type: {message_type}, "
-                                f"data: {message_data}, "
-                                f"extra: {message.extra}, "
-                                f"session: {session_id})"
-                            )
-
-                    # The logging here is for detailed trouble shooting of potential issues in this client.
-                    # If you don't see this log for a while, it means that
-                    # this receive_messages execution is no longer working for some reason.
-                    if self.logger.level <= logging.DEBUG:
-                        counter_for_logging = (
-                            counter_for_logging + 1
-                        ) % logging_interval
-                        if counter_for_logging == 0:
-                            log_message = (
-                                f"{logging_interval} WebSocket messages received "
-                                f"after the previous same log ({session_id})"
-                            )
-                            self.logger.debug(log_message)
-
+                    # just in case, checking if the value is not None
                     if message is not None:
+                        if self.logger.level <= logging.DEBUG:
+                            # The following logging prints every single received message
+                            # except empty message data ones.
+                            type = WSMsgType(message.type)
+                            message_type = type.name if type is not None else message.type
+                            message_data = message.data
+                            if isinstance(message_data, bytes):
+                                message_data = message_data.decode("utf-8")
+                            if len(message_data) > 0:
+                                # To skip the empty message that Slack server-side often sends
+                                self.logger.debug(
+                                    f"Received message "
+                                    f"(type: {message_type}, "
+                                    f"data: {message_data}, "
+                                    f"extra: {message.extra}, "
+                                    f"session: {session_id})"
+                                )
+
+                            if self.trace_enabled:
+                                # The logging here is for detailed trouble shooting of potential issues in this client.
+                                # If you don't see this log for a while, it can mean that
+                                # this receive_messages execution is no longer working for some reason.
+                                counter_for_logging += 1
+                                if counter_for_logging >= logging_interval:
+                                    counter_for_logging = 0
+                                    log_message = (
+                                        "#receive_messages method has been working without any issues "
+                                        f"(session: {session_id}, logging interval: {logging_interval})"
+                                    )
+                                    self.logger.debug(log_message)
+
                         if message.type == WSMsgType.TEXT:
                             message_data = message.data
                             await self.enqueue_message(message_data)
@@ -283,9 +268,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                                 await listener(message)
                         elif message.type == WSMsgType.CLOSE:
                             if self.auto_reconnect_enabled:
-                                self.logger.info(
-                                    f"Received CLOSE event from {session_id}. Reconnecting..."
-                                )
+                                self.logger.info(f"Received CLOSE event from {session_id}. Reconnecting...")
                                 await self.connect_to_new_endpoint()
                             for listener in self.on_close_listeners:
                                 await listener(message)
@@ -302,10 +285,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                             if message.data is not None:
                                 str_message_data = message.data.decode("utf-8")
                                 elements = str_message_data.split(":")
-                                if (
-                                    len(elements) == 2
-                                    and elements[0] == "sdk-ping-pong"
-                                ):
+                                if len(elements) == 2 and elements[0] == "sdk-ping-pong":
                                     try:
                                         self.last_ping_pong_time = float(elements[1])
                                     except Exception as e:
@@ -314,21 +294,19 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                                             f" - error : {e}, session: {session_id}"
                                         )
                             continue
+
                     consecutive_error_count = 0
+
                 except Exception as e:
                     consecutive_error_count += 1
-                    self.logger.error(
-                        f"Failed to receive or enqueue a message: {type(e).__name__}, {e} ({session_id})"
-                    )
+                    self.logger.error(f"Failed to receive or enqueue a message: {type(e).__name__}, {e} ({session_id})")
                     if isinstance(e, ClientConnectionError):
                         await asyncio.sleep(self.ping_interval)
                     else:
                         await asyncio.sleep(consecutive_error_count)
         except asyncio.CancelledError:
             if self.logger.level <= logging.DEBUG:
-                self.logger.debug(
-                    f"The running receive_messages task for {session_id} is now cancelled"
-                )
+                self.logger.debug(f"The running receive_messages task for {session_id} is now cancelled")
             raise
 
     async def is_ping_pong_failing(self) -> bool:
@@ -345,7 +323,8 @@ class SocketModeClient(AsyncBaseSocketModeClient):
             and not self.current_session.closed
             and not await self.is_ping_pong_failing()
         )
-        if connected is False and self.logger.level <= logging.DEBUG:
+        if self.logger.level <= logging.DEBUG and connected is False:
+            # Prints more detailed information about the inactive connection
             is_ping_pong_failing = await self.is_ping_pong_failing()
             session_id = await self.session_id()
             self.logger.debug(
@@ -363,14 +342,18 @@ class SocketModeClient(AsyncBaseSocketModeClient):
         return self.build_session_id(self.current_session)
 
     async def connect(self):
-        old_session = None if self.current_session is None else self.current_session
+        old_session: Optional[ClientWebSocketResponse] = None if self.current_session is None else self.current_session
         if self.wss_uri is None:
+            # If the underlying WSS URL does not exist,
+            # acquiring a new active WSS URL from the server-side first
             self.wss_uri = await self.issue_new_wss_url()
+
         self.current_session = await self.aiohttp_client_session.ws_connect(
             self.wss_uri,
             autoping=False,
             heartbeat=self.ping_interval,
             proxy=self.proxy,
+            ssl=self.web_client.ssl,
         )
         session_id: str = await self.session_id()
         self.auto_reconnect_enabled = self.default_auto_reconnect_enabled
@@ -379,31 +362,23 @@ class SocketModeClient(AsyncBaseSocketModeClient):
 
         # The first ping from the new connection
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"Sending a ping message with the newly established connection ({session_id})..."
-            )
+            self.logger.debug(f"Sending a ping message with the newly established connection ({session_id})...")
         t = time.time()
         await self.current_session.ping(f"sdk-ping-pong:{t}")
 
         if self.current_session_monitor is not None:
             self.current_session_monitor.cancel()
 
-        self.current_session_monitor = asyncio.ensure_future(
-            self.monitor_current_session()
-        )
+        self.current_session_monitor = asyncio.ensure_future(self.monitor_current_session())
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"A new monitor_current_session() executor has been recreated for {session_id}"
-            )
+            self.logger.debug(f"A new monitor_current_session() executor has been recreated for {session_id}")
 
         if self.message_receiver is not None:
             self.message_receiver.cancel()
 
         self.message_receiver = asyncio.ensure_future(self.receive_messages())
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"A new receive_messages() executor has been recreated for {session_id}"
-            )
+            self.logger.debug(f"A new receive_messages() executor has been recreated for {session_id}")
 
         if old_session is not None:
             await old_session.close()
@@ -414,16 +389,12 @@ class SocketModeClient(AsyncBaseSocketModeClient):
         if self.current_session is not None:
             await self.current_session.close()
         session_id = await self.session_id()
-        self.logger.info(
-            f"The current session ({session_id}) has been abandoned by disconnect() method call"
-        )
+        self.logger.info(f"The current session ({session_id}) has been abandoned by disconnect() method call")
 
     async def send_message(self, message: str):
         session_id = await self.session_id()
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"Sending a message: {message} from session: {session_id}"
-            )
+            self.logger.debug(f"Sending a message: {message} from session: {session_id}")
         try:
             await self.current_session.send_str(message)
         except ConnectionError as e:
@@ -442,8 +413,7 @@ class SocketModeClient(AsyncBaseSocketModeClient):
                     await self.current_session.send_str(message)
                 else:
                     self.logger.warning(
-                        f"The current session ({session_id}) is no longer active. "
-                        "Failed to send a message"
+                        f"The current session ({session_id}) is no longer active. " "Failed to send a message"
                     )
                     raise e
             finally:
@@ -466,5 +436,5 @@ class SocketModeClient(AsyncBaseSocketModeClient):
     @classmethod
     def build_session_id(cls, session: ClientWebSocketResponse) -> str:
         if session is None:
-            return None
+            return ""
         return "s_" + str(hash(session))
